#
# spec file for package pcp
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Summary:        System-level performance monitoring and performance management
License:        GPL-2.0
Group:          System/Monitoring

Name:           pcp
Version:        3.6.10
Release:        9.15

%if (0%{?suse_version} > 0)
%define pcp_gr			System/Monitoring
%define lib_pkg			libpcp3
%define lib_pkg_conflict	pcp-libs
%define lib_gr			System/Libraries
%define lib_devel_pkg		libpcp-devel
%define lib_devel_pkg_conflict	pcp-libs-devel
%define lib_devel_gr		Development/Libraries/Other
%define license_gplv2		GPL-2.0
%define license_lgplv2		LGPL-2.0
%define license_lgplv2plus	LGPL-2.1+
%define perl_version		%(perl -V:version | sed "s!.*='!!;s!'.*!!")
%else
%define pcp_gr			Applications/System
%define lib_pkg			pcp-libs
%define lib_pkg_conflict	libpcp3
%define lib_gr			Applications/System
%define lib_devel_pkg		pcp-libs-devel
%define lib_devel_pkg_conflict	libpcp-devel
%define lib_devel_gr		Applications/System
%define license_gplv2		GPLv2
%define license_lgplv2		LGPLv2
%define license_lgplv2plus	LGPLv2+
%endif

Url:            http://oss.sgi.com/projects/pcp
Source0:        ftp://oss.sgi.com/projects/pcp/download/pcp-%{version}.src.tar.gz
Source1:        pcp-rpmlintrc

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  autoconf
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  ncurses-devel
BuildRequires:  procps
BuildRequires:  pwdutils
BuildRequires:  readline-devel
BuildRequires:  perl(ExtUtils::MakeMaker)
Patch6:         pcp-xenbuild.patch
Patch9:         static_lib_perms.diff
Patch10:        pcp_legacy_init_lsb.patch
Patch13:        remove_cpan_rpaths.patch
Patch14:        rm_init_script_runlevel_4.patch
Patch15:        create-pmlogger-and-pmie-logdirs-during-install.patch
Patch16:        fix_pmie_pmlogger_startup_races.patch

%if (0%{?suse_version} > 0)
Requires:       cpp
Requires:       sysconfig
%else
Requires:       initscripts
BuildRequires:  initscripts
%if (0%{?fedora} > 0)
AutoReq:        no
%endif
%endif
Requires:       %{lib_pkg} = %{version}
Requires:       bash
Requires:       fileutils
Requires:       findutils
Requires:       gawk
Requires:       grep
Requires:       sed

%define _pmdasdir %{_localstatedir}/lib/pcp/pmdas

%description
Performance Co-Pilot (PCP) provides a framework and services to support
system-level performance monitoring and performance management. 

The PCP open source release provides a unifying abstraction for all of
the interesting performance data in a system, and allows client
applications to easily retrieve and process any subset of that data. 

#
# pcp-libs
#

%package -n %{lib_pkg}
Summary:        Performance Co-Pilot run-time libraries
License:        %{license_lgplv2}
Group:          %{lib_gr}
Url:            http://oss.sgi.com/projects/pcp/
Conflicts:      %{lib_pkg_conflict}
AutoReq:        no

%description -n %{lib_pkg}
Performance Co-Pilot (PCP) run-time libraries

#
# pcp-libs-devel
# SLE uses the legacy pcp-devel package name.
#
%package -n %{lib_devel_pkg}
Summary:        Performance Co-Pilot (PCP) development headers and documentation
License:        %{license_gplv2}
Group:          %{lib_devel_gr}
Url:            http://oss.sgi.com/projects/pcp/
Requires:       %{lib_pkg} = %{version}
Conflicts:      %{lib_devel_pkg_conflict}
%if (0%{?suse_version} > 0)
Provides:       pcp-devel = %{version}
Obsoletes:      pcp-devel < %{version}
%endif
%if (0%{?fedora} > 0)
AutoReq:        no
%endif

%description -n %{lib_devel_pkg}
Performance Co-Pilot (PCP) headers, documentation and tools for development.

#
# perl-PCP-PMDA. This is the PCP agent perl binding.
#
%package -n perl-PCP-PMDA
Summary:        Performance Co-Pilot (PCP) Perl bindings and documentation
License:        %{license_gplv2}
Group:          %{pcp_gr}
Url:            http://oss.sgi.com/projects/pcp/
Requires:       pcp >= %{version}
%if (0%{?suse_version} > 0)
Requires:       perl = %{perl_version}
%endif

%description -n perl-PCP-PMDA
The PCP::PMDA Perl module contains the language bindings for
building Performance Metric Domain Agents (PMDAs) using Perl.
Each PMDA exports performance data for one specific domain, for
example the operating system kernel, Cisco routers, a database,
an application, etc.

#
# perl-PCP-MMV
#
%package -n perl-PCP-MMV
Summary:        Performance Co-Pilot (PCP) Perl bindings for PCP Memory Mapped Values
License:        %{license_gplv2}
Group:          %{pcp_gr}
Url:            http://oss.sgi.com/projects/pcp/
Requires:       pcp >= %{version}
%if (0%{?suse_version} > 0)
Requires:       perl = %{perl_version}
%endif

%description -n perl-PCP-MMV
The PCP::MMV module contains the Perl language bindings for
building scripts instrumented with the Performance Co-Pilot
(PCP) Memory Mapped Value (MMV) mechanism.
This mechanism allows arbitrary values to be exported from an
instrumented script into the PCP infrastructure for monitoring
and analysis with pmchart, pmie, pmlogger and other PCP tools.

#
# perl-PCP-LogImport
#
%package -n perl-PCP-LogImport
Summary:        Performance Co-Pilot Perl bindings for importing external archive data
License:        %{license_gplv2}
Group:          %{pcp_gr}
Url:            http://oss.sgi.com/projects/pcp/
Requires:       pcp >= %{version}
%if (0%{?suse_version} > 0)
Requires:       perl = %{perl_version}
%endif

%description -n perl-PCP-LogImport
The PCP::LogImport module contains the Perl language bindings for
importing data in various 3rd party formats into PCP archives so
they can be replayed with standard PCP monitoring tools.

 #
# perl-PCP-LogSummary
#
%package -n perl-PCP-LogSummary
Summary:        Performance Co-Pilot Perl bindings for processing pmlogsummary output
License:        %{license_gplv2}
Group:          %{pcp_gr}
Url:            http://oss.sgi.com/projects/pcp/
Requires:       pcp >= %{version}
%if (0%{?suse_version} > 0)
Requires:       perl = %{perl_version}
%endif

%description -n perl-PCP-LogSummary
The PCP::LogSummary module provides a Perl module for using the
statistical summary data produced by the Performance Co-Pilot
pmlogsummary utility.  This utility produces various averages,
minima, maxima, and other calculations based on the performance
data stored in a PCP archive.  The Perl interface is ideal for
exporting this data into third-party tools (e.g. spreadsheets).

#
# pcp-import-sar2pcp
#
%package import-sar2pcp
Summary:        Performance Co-Pilot tools for importing sar data into PCP archive logs
License:        %{license_lgplv2plus}
Group:          %{pcp_gr}
Url:            http://oss.sgi.com/projects/pcp/
Requires:       %{lib_pkg} >= %{version}
Requires:       perl-PCP-LogImport >= %{version}
Requires:       sysstat

%description import-sar2pcp
Performance Co-Pilot (PCP) front-end tools for importing sar data
into standard PCP archive logs for replay with any PCP monitoring tool.

#
# pcp-import-iostat2pcp
#
%package import-iostat2pcp
Summary:        Performance Co-Pilot tools for importing iostat data into PCP archive logs
License:        %{license_lgplv2plus}
Group:          %{pcp_gr}
Url:            http://oss.sgi.com/projects/pcp/
Requires:       %{lib_pkg} >= %{version}
Requires:       perl-PCP-LogImport >= %{version}
Requires:       sysstat

%description import-iostat2pcp
Performance Co-Pilot (PCP) front-end tools for importing iostat data
into standard PCP archive logs for replay with any PCP monitoring tool.

#
# pcp-import-sheet2pcp
#
%package import-sheet2pcp
Summary:        Performance Co-Pilot tools for importing spreadsheet data into PCP archive logs
License:        %{license_lgplv2plus}
Group:          %{pcp_gr}
Url:            http://oss.sgi.com/projects/pcp/
Requires:       %{lib_pkg} >= %{version}
Requires:       perl-PCP-LogImport >= %{version}
Requires:       sysstat

%description import-sheet2pcp
Performance Co-Pilot (PCP) front-end tools for importing spreadsheet data
into standard PCP archive logs for replay with any PCP monitoring tool.

#
# pcp-import-mrtg2pcp
#
%package import-mrtg2pcp
Summary:        Performance Co-Pilot tools for importing MTRG data into PCP archive logs
License:        %{license_lgplv2plus}
Group:          %{pcp_gr}
Url:            http://oss.sgi.com/projects/pcp/
Requires:       %{lib_pkg} >= %{version}
Requires:       perl-PCP-LogImport >= %{version}

%description import-mrtg2pcp
Performance Co-Pilot (PCP) front-end tools for importing MTRG data
into standard PCP archive logs for replay with any PCP monitoring tool.

%prep
%setup -q
%patch6
%patch9 -p1
%patch10
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1
autoconf

%clean
rm -Rf $RPM_BUILD_ROOT

%build
%configure --with-rcdir=/etc/init.d \
	   --with-tmpdir=%{_localstatedir}/lib/pcp/tmp \
	   --with-docdir=%{_datadir}/doc/packages/pcp
make default_pcp

%install
export DIST_ROOT=$RPM_BUILD_ROOT
make install_pcp

# Fix stuff we do/don't want to ship
rm -f $RPM_BUILD_ROOT/%{_libdir}/*.a
# bnc 796448: qa/src/xmktime.c and qa/src/pthread_barrier.h have unacceptable
# license entries. Remove these along with everything under testsuite.
rm -rf $RPM_BUILD_ROOT/%{_localstatedir}/lib/pcp/testsuite

mkdir -p $RPM_BUILD_ROOT/%{_localstatedir}/run/pcp
mkdir -p $RPM_BUILD_ROOT/%{_localstatedir}/lib/pcp/tmp

%if (0%{?suse_version} > 0)
# add /etc/init.d/X symlinks at /usr/sbin/rcX
%__install -d -m 0755 ${RPM_BUILD_ROOT}/%{_sbindir}
for script in pcp pmie pmproxy pmlogger pmcd; do
	ln -s "%{_sysconfdir}/init.d/${script}" \
	      "${RPM_BUILD_ROOT}/%{_sbindir}/rc${script}"
done
%else
# default chkconfig off for Fedora and RHEL
for f in $RPM_BUILD_ROOT/%{_sysconfdir}/rc.d/init.d/{pcp,pmie,pmproxy}; do
	sed -i -e '/^# chkconfig/s/:.*$/: - 95 05/' -e '/^# Default-Start:/s/:.*$/:/' $f
done
%endif

# list of PMDAs in the base pkg
ls -1 $RPM_BUILD_ROOT/%{_pmdasdir} | egrep -v 'simple|sample|trivial|txmon' |\
sed -e 's#^#'%{_pmdasdir}'\/#' >base_pmdas.list

# bin and man1 files except those split out into sub packages
# man pages are transparently compressed so append a '*' suffix
ls -1 $RPM_BUILD_ROOT/%{_bindir} | grep -v '2pcp' |\
sed -e 's#^#'%{_bindir}'\/#' >base_binfiles.list
ls -1 $RPM_BUILD_ROOT/%{_mandir}/man1 | grep -v '2pcp' |\
sed -e 's#^#'%{_mandir}'\/man1\/#' |\
sed -e 's#$#*#'  >base_man1files.list

cat base_pmdas.list base_binfiles.list base_man1files.list > base_specialfiles.list

%pre
getent group pcp >/dev/null || groupadd -r pcp
getent passwd pcp >/dev/null || \
	useradd -c "Performance Co-Pilot" -g pcp -d %{_localstatedir}/lib/pcp -M -r -s /sbin/nologin pcp
exit 0

%if (0%{?suse_version} > 0)

%preun
%{?stop_on_removal:%{stop_on_removal pmlogger pmie pmproxy pmcd}}

%postun
/sbin/ldconfig
%{?restart_on_update:%{restart_on_update pcp pmproxy pmie}}
%{?insserv_cleanup:%{insserv_cleanup}}

%post
chown -R pcp:pcp /var/log/pcp/{pmcd,pmlogger,pmie,pmproxy} 2>/dev/null
/sbin/ldconfig
%if 0%{?suse_version} < 1131
%run_permissions
%else
%set_permissions %{_localstatedir}/lib/pcp/tmp/
%set_permissions %{_localstatedir}/lib/pcp/tmp/pmdabash/
%set_permissions %{_localstatedir}/lib/pcp/tmp/mmv/
%set_permissions %{_localstatedir}/lib/pcp/tmp/pmie/
%set_permissions %{_localstatedir}/lib/pcp/tmp/pmlogger/
%endif

%verifyscript
%verify_permissions -e %{_localstatedir}/lib/pcp/tmp/ -e %{_localstatedir}/lib/pcp/tmp/pmdabash/ -e %{_localstatedir}/lib/pcp/tmp/mmv/ -e %{_localstatedir}/lib/pcp/tmp/pmie/ -e %{_localstatedir}/lib/pcp/tmp/pmlogger/

%else

%preun
if [ "$1" -eq 0 ]
then
    #
    # Stop daemons before erasing the package
    #
    /sbin/service pmlogger stop >/dev/null 2>&1
    /sbin/service pmie stop >/dev/null 2>&1
    /sbin/service pmproxy stop >/dev/null 2>&1
    /sbin/service pcp stop >/dev/null 2>&1
    /sbin/service pmcd stop >/dev/null 2>&1

    /sbin/chkconfig --del pcp >/dev/null 2>&1
    /sbin/chkconfig --del pmcd >/dev/null 2>&1
    /sbin/chkconfig --del pmlogger >/dev/null 2>&1
    /sbin/chkconfig --del pmie >/dev/null 2>&1
    /sbin/chkconfig --del pmproxy >/dev/null 2>&1
fi

%post
chown -R pcp:pcp /var/log/pcp/{pmcd,pmlogger,pmie,pmproxy} 2>/dev/null
/sbin/chkconfig --add pmcd >/dev/null 2>&1
/sbin/service pmcd condrestart
/sbin/chkconfig --add pmlogger >/dev/null 2>&1
/sbin/service pmlogger condrestart
/sbin/chkconfig --add pmie >/dev/null 2>&1
/sbin/service pmie condrestart
/sbin/chkconfig --add pmproxy >/dev/null 2>&1
/sbin/service pmproxy condrestart

%endif

%post -n %{lib_pkg} -p /sbin/ldconfig

%postun -n %{lib_pkg} -p /sbin/ldconfig

%files -f base_specialfiles.list
#
# Note: there are some headers (e.g. domain.h) and in a few cases some
# C source files that rpmlint complains about. These are not devel files,
# but rather they are (slightly obscure) PMDA config files.
#
%defattr(-,root,root)
%{_datadir}/doc/packages/pcp
%if (0%{?suse_version} > 0)
%{_sbindir}/rc*
%endif

%ghost %dir %{_localstatedir}/run/pcp
%verify(not mode) %attr(755,root,root) %dir %{_localstatedir}/lib/pcp/tmp
%verify(not mode) %attr(755,root,root) %dir %{_localstatedir}/lib/pcp/tmp/pmdabash
%verify(not mode) %attr(755,root,root) %dir %{_localstatedir}/lib/pcp/tmp/mmv
%verify(not mode) %attr(755,root,root) %dir %{_localstatedir}/lib/pcp/tmp/pmie
%verify(not mode) %attr(755,root,root) %dir %{_localstatedir}/lib/pcp/tmp/pmlogger
%dir %{_pmdasdir}
%dir %{_datadir}/pcp
%dir %{_localstatedir}/lib/pcp
%dir %{_localstatedir}/lib/pcp/config

%{_libexecdir}/pcp
%{_datadir}/pcp/lib
%{_localstatedir}/log/pcp
%{_localstatedir}/lib/pcp/pmns
%config(missingok) %{_localstatedir}/lib/pcp/pmns/.NeedRebuild
%{_initrddir}/pcp
%{_initrddir}/pmcd
%{_initrddir}/pmlogger
%{_initrddir}/pmie
%{_initrddir}/pmproxy
%{_mandir}/man4/*
%config %{_sysconfdir}/bash_completion.d/pcp
%config %{_sysconfdir}/pcp.env
%config %{_sysconfdir}/pcp.sh
%config(noreplace) %{_localstatedir}/lib/pcp/config/pmcd/pmcd.conf
%config(noreplace) %{_localstatedir}/lib/pcp/config/pmcd/pmcd.options
%config(noreplace) %{_localstatedir}/lib/pcp/config/pmcd/rc.local
%config(noreplace) %{_localstatedir}/lib/pcp/config/pmie/config.default
%config(noreplace) %{_localstatedir}/lib/pcp/config/pmie/control
%config(noreplace) %{_localstatedir}/lib/pcp/config/pmie/crontab
%config(noreplace) %{_localstatedir}/lib/pcp/config/pmlogger/config.default
%config(noreplace) %{_localstatedir}/lib/pcp/config/pmlogger/control
%config(noreplace) %{_localstatedir}/lib/pcp/config/pmlogger/crontab
%config(noreplace) %{_localstatedir}/lib/pcp/config/pmproxy/pmproxy.options
%{_localstatedir}/lib/pcp/config/*

%files -n %{lib_pkg}
%defattr(-,root,root)

%dir %{_includedir}/pcp
%{_includedir}/pcp/builddefs
%{_includedir}/pcp/buildrules
%config %{_sysconfdir}/pcp.conf
%{_libdir}/libpcp.so.3
%{_libdir}/libpcp_gui.so.2
%{_libdir}/libpcp_mmv.so.1
%{_libdir}/libpcp_pmda.so.3
%{_libdir}/libpcp_trace.so.2
%{_libdir}/libpcp_import.so.1

%files -n %{lib_devel_pkg}
%defattr(-,root,root)

%{_libdir}/libpcp.so
%{_libdir}/libpcp.so.2
%{_libdir}/libpcp_gui.so
%{_libdir}/libpcp_gui.so.1
%{_libdir}/libpcp_mmv.so
%{_libdir}/libpcp_pmda.so
%{_libdir}/libpcp_pmda.so.2
%{_libdir}/libpcp_trace.so
%{_libdir}/libpcp_import.so
%{_includedir}/pcp/*.h
%{_mandir}/man3/*.3.gz
%{_datadir}/pcp/demos
%{_datadir}/pcp/examples

# PMDAs that ship src and are not for production use
# straight out-of-the-box, for devel or QA use only.
%{_localstatedir}/lib/pcp/pmdas/simple
%{_localstatedir}/lib/pcp/pmdas/sample
%{_localstatedir}/lib/pcp/pmdas/trivial
%{_localstatedir}/lib/pcp/pmdas/txmon

%files import-sar2pcp
%defattr(-,root,root)
%{_bindir}/sar2pcp
%{_mandir}/man1/sar2pcp.1.gz

%files import-iostat2pcp
%defattr(-,root,root)
%{_bindir}/iostat2pcp
%{_mandir}/man1/iostat2pcp.1.gz

%files import-sheet2pcp
%defattr(-,root,root)
%{_bindir}/sheet2pcp
%{_mandir}/man1/sheet2pcp.1.gz

%files import-mrtg2pcp
%defattr(-,root,root)
%{_bindir}/mrtg2pcp
%{_mandir}/man1/mrtg2pcp.1.gz

%files -n perl-PCP-PMDA -f perl-pcp-pmda.list
%defattr(-,root,root)
%if (0%{?suse_version} > 0)
%dir %{_prefix}/lib/perl5/vendor_perl/*/*-linux-thread-multi*/PCP
%dir %{_prefix}/lib/perl5/vendor_perl/*/*-linux-thread-multi*/auto/PCP
%dir %{_prefix}/lib/perl5/vendor_perl/*/*-linux-thread-multi*/auto/PCP/PMDA
%endif

%files -n perl-PCP-MMV -f perl-pcp-mmv.list
%defattr(-,root,root)
%if (0%{?suse_version} > 0)
%dir %{_prefix}/lib/perl5/vendor_perl/*/*-linux-thread-multi*/PCP
%dir %{_prefix}/lib/perl5/vendor_perl/*/*-linux-thread-multi*/auto/PCP
%dir %{_prefix}/lib/perl5/vendor_perl/*/*-linux-thread-multi*/auto/PCP/MMV
%endif

%files -n perl-PCP-LogImport -f perl-pcp-logimport.list
%defattr(-,root,root)
%if (0%{?suse_version} > 0)
%dir %{_prefix}/lib/perl5/vendor_perl/*/*-linux-thread-multi*/PCP
%dir %{_prefix}/lib/perl5/vendor_perl/*/*-linux-thread-multi*/auto/PCP
%dir %{_prefix}/lib/perl5/vendor_perl/*/*-linux-thread-multi*/auto/PCP/LogImport
%endif

%files -n perl-PCP-LogSummary -f perl-pcp-logsummary.list
%defattr(-,root,root)
%if (0%{?suse_version} > 0)
%dir %{_prefix}/lib/perl5/vendor_perl/*/PCP
%endif

%changelog
* Tue Apr  9 2013 schwab@suse.de
- Move configure run into the %%build section.
* Thu Jan  3 2013 ddiss@suse.com
- Describe xmktime.c and pthread_barrier.h licensing issues. Workaround by
  continuing to remove the testsuite; (bnc#796448).
* Tue Dec  4 2012 ddiss@suse.com
- Fix race conditions in pmie and pmlogger startup scripts.
  + Add fix_pmie_pmlogger_startup_races.patch
  + Upstream fix for regression caused by CVE-2012-5530 fix.
* Thu Nov 29 2012 meissner@suse.com
- use permissions framework for handling the worldwriteable+sticky
  bit directories. (bnc#782967)
* Wed Nov 21 2012 ddiss@suse.com
- Create pcp user and group during installation.
- Package pre-populated tmp directory. The directory must be world writeable
  (with the sticky-bit set), as it may be used by any PMDAs or client tools;
  (bnc#782967).
* Mon Nov 19 2012 ddiss@suse.com
- Remove fix_configure_path_tests.patch
  + fixed upstream.
- Remove configure_append_pcp_subdir.patch
  + fixed upstream.
- Add create-pmlogger-and-pmie-logdirs-during-install.patch
  + pmcd and pmproxy logdirs are created, pmlogger and pmie were missing.
  + Submitted upstream.
- Update to pcp-3.6.10.
  + Transition daemons to run under an unprivileged account.
  + Fixes for security advisory CVE-2012-5530: tmpfile flaws;
    (bnc#782967).
  + Fix pcp(1) command short-form pmlogger reporting.
  + Fix pmdalogger error handling for directory files.
  + Fix pmstat handling of odd corner case in CPU metrics.
  + Correct the python ctype used for pmAtomValue 32bit ints.
  + Add missing RPM spec dependency for python-ctypes.
  + Corrections to pmdamysql metrics units.
  + Add pmdamysql slave status metrics.
  + Improve pmcollectl error messages.
  + Parameterize pmcollectl CPU counts in interrupt subsys.
  + Fix generic RPM packaging for powerpc builds.
  + Fix python API use of reentrant libpcp string routines.
  + Python code backporting for RHEL5 in qa and pmcollectl.
  + Fix edge cases in capturing interrupt error counts.
- Update to pcp-3.6.9.
  + Python wrapper for the pmimport API
  + Make sar2pcp work with the sysstat versions from RHEL5,
    RHEL6, and all recent Fedora versions (which is almost
    all current versions of sysstat verified).
  + Added a number of additional metrics into the importer
    for people starting to use it to analyse sar data from
    real customer incidents.
  + Rework use of C99 "restrict" keyword in pmdalogger
    (Debian bug: 689552)
  + Alot of work on the PCP QA suite, special thanks to Tomas
    Dohnalek for all his efforts there.
  + Win32 build updates
  + Add "raw" disk active metrics so that existing tools like
    iostat can be emulated
  + Allow sar2pcp to accept XML input directly (.xml suffix),
    allowing it to not have to run on the same platform as the
    sadc/sadf that originally generated it.
  + Add PMI error codes into the PCP::LogImport perl module.
  + Fix a typo in pmiUnits man page synopsis section
  + Resolve pmdalinux ordering issue in NUMA/CPU indom setup
    (Redhat bug: 858384)
  + Remove unused pmcollectl imports (Redhat bug: 863210)
  + Allow event traces to be used in libpcp interpolate mode
- Update to pcp-3.6.8.
  + Corrects the disk/partition identification for the MMC
    driver, which makes disk indom handling correct on the
    Raspberry Pi (http://www.raspberrypi.org/)
  + Several minor/basic fixes for pmdaoracle.
  + Improve pmcollectl compatibility.
  + Make a few clarifications to pmcollectl.1.
  + Improve python API test coverage.
  + Numerous updates to the test suite in general.
  + Allow pmda Install scripts to specify own dso name again.
  + Reconcile spec file differences between PCP flavours.
  + Fix handling of multiple contexts with a remote namespace.
  + Core socket interface abstractions to support NSS (later).
  + Fix man page SYNOPSIS section for pmUnpackEventRecords.
  + Add --disable-shared build option for static builds.
- Update to pcp-3.6.6.
  + Added the python PMAPI bindings and an initial python client
    in pmcollectl.  Separate, new package exists for python libs
    for those platforms that split out packages (rpm, deb).
  + Added a pcp-testsuite package for those platforms that might
    want this (rpm, deb again, mainly)
  + Re-introduced the pcp/qa subdirectory in pcp and deprecated
    the external pcpqa git tree.
  + Fix potential buffer overflow in pmlogger host name handling.
  + Reworked the configure --prefix handling to be more like the
    rest of the open source world.
  + Ensure the __pmDecodeText ident parameter is always set
    Resolves Red Hat bugzilla bug #841306.
* Tue Nov 13 2012 ddiss@suse.com
- Ensure pmlogger and pmie temporary state is always placed under
  PCP_TMP_DIR.
* Mon Nov 12 2012 ddiss@suse.com
- Specify the PCP temporary file directory at configure time using the
  - -with-tempdir= argument.
* Fri Nov  9 2012 ddiss@suse.com
- Use mktemp for the placement of init script temp files. Place global
  temp files under run_dir; (bnc#782967).
* Wed Aug 15 2012 ddiss@suse.com
- Update to pcp-3.6.5.
  + Fixes for security advisory CVE-2012-3418; (bnc#775009).
    o Add field validation to PCP instance PDU (Red Hat #841240)
    o Fix __pmDecodeInstanceReq heap buffer overflow (Red Hat #841284)
    o Fix __pmDecodeText heap overflow (Red Hat #841249)
    o Multiple issues in result PDU decoding (Red Hat #841159)
    o Fix __pmDecodeNameReq buffer overflow (Red Hat #841180)
    o Add length checks to __pmDecodeLogControl (Red Hat #841290)
    o Add size check to __pmDecodeIDList (Red Hat #841112)
    o Fix __pmDecodeNameList buffer overflow (Red Hat #840920)
    o Add missing __pmDecodeFetch namelen checks (Red Hat #841183)
    o Add length checks to __pmDecodeProfile (Red Hat #841126)
    o Add length checks to __pmDecodeCreds (Red Hat #840822)
  + Workaround for security advisory CVE-2012-3419; (bnc#775010).
    o Split the Linux kernel and proc PMDAs to prevent information
    leakage in default installs - esp. /proc/pid/maps exposure,
    but other proc metrics as well - and no longer export process
    metrics by default (Red Hat #841702)
  + Fixes for security advisory CVE-2012-3420; (bnc#775011).
    o Memory leak in pmcd DoFetch error path (Red Hat #841298)
    o Memory leak in __pmGetPDU in-band signalling (Red Hat #841319)
  + Fixes for security advisory CVE-2012-3421; (bnc#775013).
    o Resolve event-driven programming flaw in pmcd (Red Hat #841706)
  + Correct buffer unpinning logic in a PMNS traversal error path
    o Red Hat bugzilla bug #847314.
  + All of the above issues were identified by Florian Weimer of the
    Red Hat Security Team, who also assisted extensively in fixing
    and testing; a huge thank you to Florian from all PCP developers
    and users!
  + Add modern gcc/glibc security protection mechanisms where
    available.  Thanks to the Frank Eigler.
  + Harden all boundary checking in the remaining PDU decoders.
  + Resolve an issue with configure script checking for the init(1)
    process on Fedora 17 (and other systems using systemd).  Thanks
    to Lukas Berk.
  + pmdaelasticsearch only reports on nodes in the cluster now,
    and not other client nodes.  Thanks to Nigel Donaldson.
  + Added interfaces to PCP::PMDA Perl module to allow PMDAs to
    use a hash instance domain (instead of int/string array).
    These make use of the pmdaCacheOp(3) interfaces - the hash
    keys are the (external) PCP instance names, and the value
    associated with each key is an opaque reference.
  + Added an interface to allow PMDAs to register event queues
    with existing clients (pmdaEventNewActiveQueue).
  + Initial version of the (experimental) bash tracing PMDA.
* Mon Jul 30 2012 ddiss@suse.com
- use addFilter for rpmlintrc, setBadness is not acceptable for Factory.
* Thu Jul 19 2012 ddiss@suse.com
- Spec file cleanups following feedback from Sascha.
  + Do not remove the buildroot as part of %%install
  + Use %%suse_version rather than %%_vendor
  + Add pcp-rpmlintrc script for devel-file-in-non-devel-package errors
  + Remove runlevel 4 references from init scripts
  + Add explicit perl version Requires
* Wed Jun 27 2012 ddiss@suse.com
- Remove fix_cpan_pmda_manifest.patch, no longer needed with fixed
  upstream tarball.
* Mon Jun 18 2012 ddiss@suse.com
- Remove invalid cpan/PMDA manifest entry.
* Fri Jun 15 2012 ddiss@suse.com
- Update to pcp-3.6.4.
  + Fix build on s390x platform (thanks to Dan Horak)
  + Rethink order of PATH setting for pcp start scripts, to ensure
    binaries from other packages with names that conflict with pcp
    binaries are not found ahead of the same-named pcp binary.
* Wed Jun  6 2012 ddiss@suse.com
- Use upstream based spec file to support combined SUSE/RH builds;
  (bnc#732763).
- Update to pcp-3.6.3.
  + Revert initial attempt at getting configure --prefix option to
    make sense for local developer PCP installations
  + Fix RPM changelog typo in in-tree spec file
  + Further work on Debian/kFreeBSD port (thanks to Robert Millan)
- Update to pcp-3.6.2.
  + Fix Debian builds on FreeBSD (missing header files)
  + Resolve Debian startup script (compat) lintian issue
  + Resolve FreeBSD kernel PMDA build issue with PCP not installed
    in the build root already.
- Update to pcp-3.6.1.
  + Resolve final Mac OS X pthreads build issues
  + Debian packaging improvements for split pmlogger/pmcd scripts,
    perl module pieces, and other lintian reported issues
  + Update the startup script dependencies for /var use
  + Support --prefix=... and --exec-prefix=... configure options
  + Relaxed the "are you running as root?" test in startup scripts
  + Win32 build updates and improvements
  + Cache /proc/stat file handle in Linux kernel agent to reduce
    syscalls on the most commonly fetched metric subtree
- Update to pcp-3.6.0.
  + Thread-safe libpcp, including additional re-entrant and thread-safe
    variants for some routines
  + Retire all asynchronous routines from libpcp
  + Retire all V1 protocols and services (archive format, PMAPI and
    PMDA_INTERFACE)
  + PMNS moves to ASCII only (no binary PMNS)
  + Rework "init" scripts, splitting pcp into pmcd and pmlogger
  + Update elasticsearch PMDA to 0.19+, new transport and shard metrics
  + Updates to PMDA new event queueing interfaces for agents wishing to
    export that class of performance data.
  + First round of Coverity cleanup fixes incorporated.
  + Initial version of the SNMP PMDA, thanks to Hamish Coleman.
  + Updates to postgres PMDA to export additional recovery metrics.
- Update to pcp-3.5.11.
  + Update FSF contact address in copyright notices to keep
    rpmlint happy.
  + Fix instance domain checks in elasticsearch PMDA.
  + Make KVM PMDA to run as root once more (permissions issues).
  + Integration of pmlogger_daily with pmlogrewrite.
  + Fix pmlogger_merge corner case for empty archives.
- Update to pcp-3.5.10.
  + Support new 0.18+ elasticsearch metrics.
  + Fix handling of elasticsearch version metric cluster.
  + Fix trace PMDA build issues.
  + Fix some Win32 build issues.
  + Run with reduced privileges for more of the perl PMDAs.
  + Name Solaris load average metric consistently.
  + Small metric documentation tweaks for Solaris PMDA.
- Update to pcp-3.5.9.
  + Add rc script support for condrestart, and condrestart the pcp,
    pmie and pmproxy services after an RPM install or upgrade.
  + Fix a bug where hinv.ndisk is incorrect if CLUSTER_PARTITIONS
    hasn't yet been refreshed immediately following a restart.
  + Implementation of client event queueing logic for all PMDAs to
    share (all PMDAs wishing to support event metrics, that is).
  + New manual pages for new PMDA event queueing interfaces.
  + PostgreSQL PMDA, supporting versions 9.0 and 9.1 (at least).
  + Reserved ID 111 for Samba Clustered Trivial Database PMDA.
  + Add perl interface to allow PMDAs to drop priveleges
  + Add an elasticsearch version metric.
  + Correct perl module type detection logic for 32/64-bit systems.
  + Small pmlogconf source and man page fixes.
  + Rework flex usage to resolve build warnings.
  + Make Darwin CPU metrics 64 bit.
  + Add (long) opaque key support to libpcp_pmda.
  + Add pmdaCacheStoreInst() routine to libpcp_pmda.
  + Added mssql PMDA for SQL server Dynamic Management View stats.
  + Add pmlogrewrite(1) to rewrite archives (fix inconsistencies).
  + Fix a cgroup option parsing error on consecutive fetch calls.
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Thu Nov 10 2011 meissner@suse.de
- wildcard a bit to make it package on ppc
* Wed Aug 10 2011 ddiss@suse.de
- Update to pcp-3.5.8.
  + Rework rsyslog PMDA to remove Switch use, very odd behaviour
    observed on RHEL5.2 (mysteriously failing to compile).
  + Add in Kens scripting defenses against dodgey toolchains.
* Tue Aug  9 2011 ddiss@suse.de
- Update to pcp-3.5.7.
  + Fix build issue on SLES11 SP1 IA64 systems.
  + Improved rsyslog PMDA handling of queue metrics.
  + Add open file-descriptor count metric to the Linux PMDA.
  + Implement logger PMDA line-oriented event mode.
  + Add regular expression based event filtering in logger PMDA.
  + The default pmcd.conf now has an access control section, and
    all remote store operations are blocked by default.
* Mon Aug  1 2011 ddiss@suse.de
- Update to pcp-3.5.6.
  + Fix warning from pmie_daily with some /bin/pwd versions.
  + Numerous Debian packaging updates for lintian cleanliness.
  + Fixed typos in several man pages.
  + Added ElasticSearch PMDA.
  + Fix build on RHEL4 with older sys/queue.h variant.
* Thu Jul  7 2011 ddiss@suse.de
- Update to pcp-3.5.5.
  + Resolve Debian packaging issues preventing new uploads.
  + Fix warnings from pmie_check with some /bin/pwd versions.
- Update to pcp-3.5.4.
  + Fix warnings from pmlogger_check with some /bin/pwd versions.
- Update to pcp-3.5.3.
  + Remove reliance on a cpp binary being installed locally.
  + Ensure compressed pmie log files are also cleaned up daily.
  + Extend the event store mechanism to be more generally useful.
  + Add memory limiting functionality to pmdalogger.
  + Add SQLServer metric for user settable queries.
  + Fix potential sigsegv in pmprobe fetching multiple live values.
  + Perl changes for Solaris.
  + Fix Fedora15 build relating to handling of systemd.
  + Solaris pmda zpool_vdev_name() api change.
  + Update sar2pcp for sysstat version 9.1.7.
  + Resolve realloc issue in event metric handling in libpcp_pmda.
- Update to pcp-3.5.2.
  + pmlogreduce - fix 2 problems (memory leak, additional mark records)
  + Initial version of pmdalogger, from David Smith, a log monitoring
    PMDA exporting event metrics.
  + Make Windows drive instance domain code less chatty.
  + RC scripts and pmie_check - Mac OS X porting
  + pmlogger_check - symbolic link issue fixed
  + Add in the rsyslog PMDA (http://www.rsyslog.com)
  + Extend PCP::PMDA so that the log tail mode can be used on named papes.
  + Numerous updates to the Perl packaging infrastructure
  + Fix build when $HOME is not set.
  + pmlogconf - another non-posix awk issue fixed
  + Darwin pmda - filesys.maxfiles metric
  + pmie_daily - assorted minor fixups
  + Unix domain socket issue found on Mac OS X
  + pmcd config parsing error handling cleanup
  + Quieten pmevent output in the absence of new events.
  + Pass process ID out on success of __pmProcessCreate.
  + pmdaproc.sh - add PMDA_INTERFACE_5 support
  + pcp_completion.sh - add pmevent for bash metic completion
  + pmevent - add instance domain support
  + Bugfix: fetching hinv.cpu.* aborts if cpu indom is not initialized
  + Rearrange the per-CPU intr metrics on Linux to use dynamic namespace
  + Add perl modules into Mac OS X installations
  + Additional vmstat metrics added to Linux kernel PMDA
  + Fix pmieconf after syscall metrics went away on Linux
  + pmevent - new util to report event records, with instance domain support
  + sample PMDA - instance domain for event records metric
  + pmval, pminfo - man page typo corrections
  + pmval - fix typo in error message
  + pmlogextract, pmlogreduce - auto volume switch at 2^31 bytes
  + pmnscomp - defaults to Version 2 of the compiled PMNS
  + Remove unconditional diagnostic in MMV agent, log spam
  + Rework the code that uncompresses archives for Win32
  + Updates to Win32 makefiles to get a clean package build
  + Enable compressed log processing for Windows as well
  + Sample event consumer code for Windows ETW
  + Update PDH Win32 headers to use those from current mingw-m64 tree
  + Win32 socket error messages are reporting correctly
  + Great strides in getting error reporting correct on Windows
  + Add Win32 pthread wrapper for threading work on Windows
  + Add PowerDNS recursor stats to the pdns PMDA
- Update to pcp-3.5.0.
  + Infrastucture support for doing distributed event tracing with PCP.
    This includes a new metric type (PM_TYPE_EVENT), cunning mechanisms
    for encoding event records in pmResults, and providing PMDAs with
    per-client context connection information allowing agents to track
    which clients have seen which parts of a trace stream so far.  Some
    reference uses of these extensions can be seen in pmdasample and in
    the pmcd PMDA as well.
  + Transparent support for archive de-compression by clients.
  + Manual page formatting errors corrected.
  + Fix a pmDupContext memory corruption issue seen with derived metrics.
  + Added a one-trip optimisation/guard to pcp.env
  + Improved pmdaFetch and pmdaFetchCallback man pages with respect to
    return codes and value memory allocation models.
  + Fix for Windows unintentionally allowing multiple pmcd processes
    to startup and bind to the same port, with "undefined" results.
  + Fix Windows services interaction, preventing pmcd service stop.
  + Fix Mac OS X scandir memory leak on empty directories.
  + Fix Mac OS X mem.util.wired metric, was exporting the wrong value.
  + Correct the handling of SLES11 distro identification (lsb-release
    file not used again, on SuSE Linux distributions).
  + Fix postfix PMDA log file path handling for Redhat Linux distros.
  + Extend Perl PMDA interfaces to allow additional metrics to be
    added at runtime (now makes use of dynamic namespace support).
  + Set KEEPALIVE option on pmproxy client sockets, mirroring pmcd
    behaviour and reducing open file descriptor pressure.
  + Improvements to the native Windows version of pmlogger, preventing
    it from exiting prematurely thanks to a socket read race condition.
  + Fix /proc/interrupts parser in Linux PMDA, thanks to Arthur Kepner.
* Mon Jan 24 2011 ddiss@suse.de
- Update to pcp-3.4.0.
  + Add new libpcp_import C API library to pcp-libs.
  + Add perl-PCP-LogImport RPM sub-package for libpcp_import perl binding.
  + Add pcp-import-* RPM sub-packages containing front-end tools for
    importing data from sar, iostat, generic speadsheets and mrtg.
  + Major Solaris PMDA updates: CPUs, vnode ops, disk stats and disk queue
    stats, switch to using pmid clusters, internal timers, ZFS Adjustable
    Replacement Cache stats, new help text, memory metrics, fsflush stats.
  + Use Solaris devinfo to get information about pretty disk names.
  + Fix a memory leak in Perl PMDA wrapper string handling.
  + Use correct structure to extrace zpool write counters in Solaris PMDA.
  + pmafm now supports multiple -a arguments.
  + Fix pmie multiple -a options bug.
  + Fix pmdaInit() callback handling where it did not handle all the
    interface versions correctly.
  + Quote filenames reported by pmwtf, else awk can get confused.
  + Fix pmdawindows missing metrics help text.
  + Add network interface speed metrics into pmdawindows.
  + Fix pmdalinux handling of long network interface names.
  + Updated pmdaapache to use cross-platform http library.
  + Updated pmdaapache install process to allow port selection.
- Update to pcp-3.3.3.
  + Fix two off-by-one errors in NUMA metrics in Linux PMDA.
  + Rework timezone environment variable handling to be able to
    coexist more peacefully with Perl.
  + Remove Fedora specfile now that this is in Fedora CVS.
- Update to pcp-3.3.2.
  + Fix FreeBSD build and packaging issues affecting Debian.
  + Move PCP::Glider Perl code into core PCP with other Perl modules.
  + Avoid a mingw64-compiler-runtime bug in gettimeofday.
  + Fix spec file issue in Fedora/RHEL builds.
  + Add in the gpsd PMDA.
- Update to pcp-3.3.1.
  + Fix a sigsegv in pmdalinux in the kernel.pernode.cpu metrics.
  + Don't kill dbpmda if namespace cannot be loaded.
  + Resolve a Windows build error under latest toolchain.
  + Some minor pmieconf and pmimport related cleanups.
- Update to pcp-3.3.0.
  + Rework pmlogconf utility - version 2.0 ondisk format.
  + Initial support for Linux kernel cgroup subsystem, using dynamic
    metrics (cpu sets, cpu sched, cpu acct, memory, ...)
  + Fix per-process I/O (proc.io.*) metric values.
  + Fix potential SEGV in derived metrics when pmcd connection lost.
  + Fix to allow pmlogger to log derived metrics.
  + Fix open file descriptor leak in Linux disk scheduler code.
  + Postfix PMDA updated to report aggregate stats from mail.log parsing.
  + Add per-node CPU metrics to Linux kernel agent.
  + Integrate pmieconf into the build, modernisation and porting work.
  + Add install-sh to the set of pcp-internal programs for external code.
  + Improved checking of PMDA domain numbers.
  + Allow use of SunStudio compiler on Solaris.
  + Add load average metrics to Solaris kernel agent.
  + Windows 7 porting work.
  + Make Win32 build work with more recent versions of gcc and Perl.
  + Fix pmie [no]match_inst botch, tweak sleepTight reporting.
  + Allow \$ for pmie regular expressions.
  + Ensure pmlogger doesn't write extended pmcd host syntax as hostname.
  + Switch over to not using local context for bash completion.
  + Improve Lustre agent metric help text.
  + Added a readonly filesystems metric into Linux kernel agent.
  + Ensure xfs.buffer metrics are always properly refreshed.
  + Add Linux kernel statistics related to XFS btree operations.
- Update to pcp-3.2.1.
  + Export information about ZFS snapshots
  + Correct accounting of PMNS size in a libpcp_pmda helper routine.
- Update to pcp-3.2.0.
  + Change how PM_CONTEXT_LOCAL determines available PMDAs:
    rework local context code to retire $PMDA_LOCAL_*, build DSO table
    from pmcd.conf at run-time, new __pmLocalPMDA and __pmSpecLocalPMDA
    routines in libpcp, -K options for pminfo, pmval and pmprobe.
  + Make some pmda dynamic name operations take (const char *) args.
  + Fix bash completion so dynamic names expanded, and stderr culled
    (culling DSO agent initialisation messages).
  + Improve pmlogger handling of alias names (same PMID, different names).
  + Honour the -T command line option in pmlogreduce.
  + Resolve an MMV issue evident in the Mac OS X installer, which resulted
    in failed dmg (binary) installation attempts.
  + Solaris startup script improvements.
  + Add details of the extended hostname syntax to pcpintro(1).
  + Fix a memory leak in pmdawindows help text handling.
  + Fix a memory leak in pmdammv help text handling.
  + Add anonymous huge page Linux memory utilisation metric.
  + Fix local context reporting of help text.
  + Solaris man page build changes.
  + Clean up diagnostic messages in pmlogextract.
  + Teach pmdaproc about Solaris' ping.
  + If pmstat fails to connect to local pmcd, fallback to local context.
  + Mark as const the final (requested units) pmConvScale argument
  + Clean out SGI-isms from build related files (no longer used by SGI).
  + Fix mem.numa.util.NFS_Unstable metric.
  + Removed pmdajstat, this has long been superceded by the capabilities
    of the Parfait package for instrumenting Java applications with PCP.
- Update to pcp-3.1.2.
  + Add indom save and restore logic into Windows PMDA.
  + Fix a typo in the Postfix PMDA.
  + Update and extend /proc/meminfo stats on Linux.
  + Improve handling of monitored process in pmdammv, especially
    when the monitored process exits (pmns not cleaned up before).
- Update to pcp-3.1.1.
  + Use a better MMV generation number, using all bits available.
  + Fix a metric count calculation error in pmdammv.
  + Add precision argument (-p) to pmwtf.
  + Added an open socket sockname command to dbpmda.
  + Remove use of grep -q, unavailable on OpenSolaris.
  + Couple of trivial build fixes for the Win32 platform.
- Update to pcp-3.1.0.
  + Derived metric support.
  + Fix a memory leak in the Solaris kernel PMDA.
  + Extract information about network links on Solaris.
  + MMV PMDA (DSO) is now installed and enabled by default.
  + Reintroduced MMV support for cross-(mmap-)file instances.
  + Bug fix in pmdammv which was capable of causing SIGSEGV.
  + Add dbpmda readline support (and packaging dependencies).
  + Add in -Z option to pmwtf, to pass through to pmlogsummary.
  + Export NUMA memory statistics from the linux kernel.
  + Make pmie_check work on Solaris.
  + Make perdisk stats part of the zpool hierarchy.
  + dbpmda fix for name lookup and dynamic metrics.
  + Add a new PMDA exporting the Postfix queue lengths.
  + BuildRequires initscripts for %%{_vendor} == redhat.
- Update to pcp-3.0.2.
  + Improvements and fixes to PCP::PMDA perl module.
  + Added the SQL Server dtsrun log file parser PMDA.
  + Switch MMV PMDA to use dynamic namespace interfaces, which resolves
    long-standing spurious EAGAIN error on reconfiguration.
  + Separate out the Infiniband and cluster PMDAs into their own
    package - removing dependencies and configure complexities from
    pcp into specialised, layered packages.
  + Configure packaging to use libexecdir for private pcp binaries,
    if supported on the platform (also honour --libexecdir configure flag)
  + Add sysfs.kernel metrics cluster to Linux PMDA.
- Update to pcp-3.0.1.
  + Reverted rc scripts default start/stop settings back to how
    it was in 2.9.3-1, for Debian bug #544350. On Red Hat platforms,
    the RPM spec overrides this to be chkconfig off by default.
  + Lexical analyser tweaks (various tools) to work on Windows.
  + pmlogextract change timezone selection algorithm, add -f for old behaviour
  + configure.in clean up more thoroughly on Mac OS X
  + Get pcp building on Debian GNU/kFreeBSD port.
  + Add missing return statement causing incorrect mem.util on Win32.
  + Improved support for Slackware distro makepkg packaging
  + Solaris fixes: pass information about compiler into Perl PMDA makefiles,
    don't change pointer types of pmCtime's arguments, deal with default lex
  + Move Infiniband and Cluster PMDAs to a stand-alone packages
  + Trim the set of RPM files marked as %%config to just those
    that are actually likely to be edited (rpm -qlcv pcp pcp-libs).
- Update to pcp-3.0.0.
  + PMDA_INTERFACE_4 and the support of dynamic subtrees of the PMNS
    where the PMDA (not PMCD) maintains knowledge of the PMNS.
  + RPM packaging split into pcp, pcp-libs and pcp-libs-devel
    pcp-libs is common - it's required by pcp and by pcp-libs-devel but
    pcp and pcp-libs-devel can be installed with or without each other.
  + Added separate specific licenses for the new subpackages,
    particularly pcp-libs, which is LGPL.
  + Added ldconfig %%post and %%postun scriptlets for -libs
  + Don't explicitly require Infiniband libs, since they're libs and RPM
    figures it out
  + No need to explicitly BuildRequire gcc-c++ libstdc++-devel
  + Add BuildRequires on perl-ExtUtils-MakeMaker
  + Remove explicit ia64 Requires: libunwind
  + Preserve generated gram.tab.c in several places since debuginfo needs it
  + Create %%{_localstatedir}/run/pcp and ship it (so it'll be removed)
  + Use %%doc in spec for CHANGELOG COPYING INSTALL README VERSION.pcp pcp.lsm
  + Tweak configure to move PCP_BINADM_DIR out of /usr/share, into /usr/lib.
    Arch dependent binaries should not be installed below /usr/share.
  + Delete unneeded "explicit script interpreter" in several places
    to keep rpmlint happy
  + Remove setuid from pmpost, not needed (and not in debian either)
  + Nuke the migrate_pcp_var_dir, script and it's %%post scriptlet
  + Default "chkconfig off" for all PCP services (retain settings on upgrade)
  + Clean-up and simplify the %%post scriptlets (rather dramatically)
  + Don't ship static libraries in Fedora, we have the debug package for that
  + Install .NeedRebuild, add to %%files and remove crud from %%post scriptlets
  + Added %%changelog in RPM spec and moved %%files to end before %%changelog
  + Move demos, examples and demo PMDAS to the libs-devel package since they
    are not used for production (but are useful for devel and needed for QA).
  + Don't install trace demo binaries since src is installed anyway
  + Reconciled build/rpm/pcp.spec.in with build/rpm/pcp_fedora.spec
  + Integrated RPM packaging support for perl-PCP-PMDA and perl-PCP-MMV
    (but perl-PCP-Logsummary is not currently shipped in RPM packages)
  + RPM build requires perl(ExtUtils::MakeMaker) rather than
    perl-extutils-makemaker (this is the standard notation)
  + For easier upgrades, the perl PMDAs only really require pcp >= package
    version (until we change or extend an API).
  + ReplacePmnsSubtree fix bad signal handling botch (affecting MMV PMDA)
  + Fix pmcd.timezone metric such that value updates on daylight savings
    (or other timezone) changes.
  + Initial packaging work for Slackware Linux, thanks to Roman Revyakin.
- Update to pcp-2.9.3.
  + configure.in fix for Windows iptypes.h header.
  + Fixup Windows SQL Server metrics on 64 bit platforms.
- Update to pcp-2.9.2.
  + Final iteration on pmval sample count changes.
  + Build fallout on Mac/Win32 in MMV client library.
  + Tidy configure.in sys/stat time field/types handling for Alpha builds.
- Update to pcp-2.9.1.
  + Fix a long-standing pmval sample count miscalculation.
  + Add missing runlevels and dependencies in start scripts.
  + Fix a segv observed in the Windows PMDA accessing SQL Server metrics.
  + Fix logic error causing wrong Windows version to be reported sometimes.
  + Add kernel.all.uptime to the Windows kernel agent.
  + Initial version of the (perl-based) Samba PMDA.
  + Fixes to pmdasimple.pl so it functions correctly on all platforms.
  + Add PCP::PMDA helper routines for determining native long sizes.
  + Extend MMV to allow teardown of MMV file, and set errno on failure.
  + Initial stable (1.00) version of MMV Perl interface.
  + Correct the metric units for several Windows per-process memory metrics.
  + Add network metrics to Solaris PMDA
  + Report ZFS statistics from Solaris PMDA
  + Export zpool stats from Solaris PMDA
  + Generate packages for Solaris
  + Allow user to choose her compiler (proper use of AC_PROG_CC)
- Update to pcp-2.9.0.
  + Fix Linux PMDA issue with -fstack-protector gcc option.
  + Get socket daemon PMDAs working with Win32 pmcd.
  + Bind 9.4 PMDA.
  + PowerDNS PMDA.
  + Fix atexit handling in the Perl PMDA module.
  + Fix a duplicate PMID in the MySQL PMDA.
  + Infiniband PMDA improvements and man page.
  + Minor packaging tweaks for rpm and deb formats.
- Update to pcp-2.8.12.
  + Bug fixes in Zimbra and MySQL PMDAs.
  + Fix memory leaks in the Perl PMDA interface.
  + Fix the Mac OS X pmdadarwin metric table direct mapping.
- Update to pcp-2.8.11.
  + Rework namespace file generation for Perl PMDAs.
- Update to pcp-2.8.10.
  + RPM packaging fixes for Perl modules.
- Update to pcp-2.8.9.
  + Remove Cygwin support, we're now committed to native Win32
    port - first production install yesterday, hooray!
  + Further Win32 work - wrapper batch files for shell scripts
    run as commands, moved daemon configs into $PCP_DIR/etc,
    bug fixes to process creation code.
  + Significant work on the MMV PMDA, including revamped API,
    Perl API, updated on-disk support with string values and
    help text support, amongst other changes.
  + Fix build of Perl PMDA module when PCP not installed.
  + Fix Zimbra PMDA status metrics.
- Update to pcp-2.8.8.
  + Added a Zimbra Collaboration Suite PMDA.
  + Build fixes for OpenSolaris.
  + Perl PMDA fixes in tail mode.
  + Correct physical memory reporting in Windows PMDA on 32 bit
    machines.
  + Other small tweaks and improvements to Windows PMDA also.
- Update to pcp-2.8.7.
  + Windows PMDA major rework to improve memory footprint.
  + Yet another Mac OS X build issue resolution.
- Update to pcp-2.8.6.
  + Fix build on Mac OS X after lex warning cleanups.
  + Fix pmdate build when PCP headers not in the root.
  + A single PMNS domain number file now used in-tree.
  + Added tmpfs filesystem metrics to Linux PMDA.
- Update to pcp-2.8.5.
  + Packaging tweaks for Debian (builddefs/rules moved).
  + Make timezone manipulation in Windows work (mimic MSYS).
  + Numerous warnings fixed.
  + Several changes to tempfile handling for Vista.
  + Make setting pcp_rc_dir in configure.in more robust.
  + Further pathname separator auditing for Windows.
  + Fixed a libpcp_gui linker issue on Mac OS X.
- Update to pcp-2.8.4.
  + Descend into src/bashrc.  D'oh!
- Update to pcp-2.8.3.
  + Bash auto-completion of metric names.
  + Fix a memory leak in xfs project quotas metrics.
  + Several Win32 fixes for Windows Server 2008.
  + Add Linux per-CPU and aggregate "guest" CPU utilisation metrics.
  + Add a pmlogsummary option to report a "header" line (-H).
  + Add optional pmstat support for time control via pmtime.
  + Add pmcd.client.* metrics for identifying connected clients.
- Update to pcp-2.8.2.
  + Fix pmie bug in the handling of && and || operators.
  + Improve daily pmie/pmlogger script behaviour.
- Update to pcp-2.8.1.
  + Fix build issue with libpcp_mmv - would not build-from-source
    if <pcp/pmapi.h> was not in the root filesystem.
  + Finer control of pmie2col(1) reporting precision.
- Update to pcp-2.8.0.
  + Linux netfilter (IP connection tracking) PMDA included
  + Memory Mapped Value (MMV) PMDA and client library included
  + Linux bonding (bonded network interface) PMDA included
  + Lustre PMDA included
  + Added pcp_gui library as pcpmon replacement, supporting the
    new (open source) version of pmtime for console tools.
  + Perl PCP::LogSummary module included.
  + KVM (Linux Kernel Virtualisation layer) PMDA
  + Infiniband PMDA included
  + VMware PMDA included
  + Perl PCP::PMDA module completed, stabilised and incorporated.
  + Default pmcd and pmproxy ports changed to IANA registered ones.
    ( The old behaviour - i.e. both original and IANA ports - is
    still available using PMCD_PORTS and PMPROXY_PORTS variables ).
- Update to pcp-2.7.7.
  + Infiniband metric enhancements
  + Handle missing "which" binary during rpm installation
  + Added new quota metrics (XFS project quota)
  + Aggregate and per-CPU hypervisor "steal" time metrics added
  + NFS v4 metrics
  + commitLimit meminfo metric added
  + Namespace locking fix in pmdaproc.sh
  + Additional Windows memory metrics
  + Several pmie fixes from Ken
  + Kens pmlogreduce archive corruption fix
  + Kens pmproxy PDU size fix
  + Nathan's pmlogsummary sum calulation fix
  + Added a (cheap) runnable processes metric.
- Update to pcp-2.7.4.
  + MaxOSX and Debian/Ubuntu build/package fixes
  + Add sqlserver active_transactions metrics to the Windows PMDA.
  + Fix a pmie_check typo causing mis-identification of pmie processes.
  + Allow pmie and/or operators to function with some data missing.
  + Resolve path naming issues with more recent versions of autoconf.
  + pmlogsummary report sum option
  + pmval kmtime support
  + Additional Linux SNMP metrics
  + Fix Linux vmstat nr_slab metrics
  + Make pcp status command report build version
  + Windows split_io metrics
  + Fix pmdapmcd empty pmie instance
  + pmdamailq filename regex
  + Windows TCP metrics
  + pmie log file rotation
  + Changed the default compression program to be bzip2(1)
- Update to pcp-2.7.3.
  + add network.ib.control to timeout infiniband stats workthread
  + add mem.util.anonpages
- Update to pcp-2.7.2.
  + pcp doc updates
  + pmdalinux death from open file descriptors: pclose needed in network.ib
  + network.ib stats updated to cope with OFED 1.2 changes
  + some numa.link fixes for shub2 & NL4
  + Improve start/stop times of pmcd,pmlogger,pmie
  + create portable pmsleep (subsecond sleep) exe
- Update to pcp-2.7.0.
  This log has been allowed to lapse for some time. Blanket catch-up..
  the following PVs describe changes made in that time:
  + 947510 - UNIX95 patches break pcp tools
  + 948548 - [SUSE#182852] Buffer overflow in linux proc_pmda
  + 948551 - Update pcp configure and build infrastructure
  + 948799 - Move telnet-probe to oss part of pcp
  + 948958 - *nodeid conversions have inconsistent naming
  + 952623 - possible use-after-free of pmProfile objects used by pmda
  + 952932 - pcp-open RPM requires libpcp.so.2 but doesn't provide it
  + 953015 - Promote libpcp_pmc to DSO
  + 953301 - Update irix pcp bits
  + 953876 - Use swap.pagesin/pagesout instead of swap.in/.out in pmstat
  + 954035 - Update macosx build infrastructure
  + 954165 - pmdumptext reports wrong time with sub-second intervals
  + 954173 - pmReceiveNamesOfChildren returns bogus value
  + 954203 - pmnscomp generates bogus binary pmns files
  + 954342 - Add support for FreeBSD
  + 954343 - Update windows pmda
  + 954432 - Use a pidfile to stop pcp
  + 954652 - telnet-probe ate my arguments
  + 954842 - Update qa on sles10 for pcp 2.5 and 2.6
  + 956190 - add IB traffic stats to linux PMDA
  + 956199 - pmlogsummary double free causes graph failures
  + 957598 - add debuginfo to pcp-open build in mangrove
  + 957758 - valgrind finds "invalid read of size 8" etc in __pmStuffValue
  + 957884 - need network.ib.status for per-port IB status and description
  + 958273 - If OFED is installed but no ports are found, return PM_ERR_VALUE from refresh_ib
  + 958379 - IB PMDA broken (port num appearing twice in perfquery calls)
  + 958476 - path to pmie_check binary incorrect in pmie crontab config file
- Update to pcp-2.5.0-2.
  + 947602 - pmdas/aix/common.h is missing from the tarball
* Thu Feb 11 2010 jengelh@medozas.de
- SPARC requiers use large PIC
* Wed Jun 10 2009 coolo@novell.com
- filter out -fomit-frame-pointer to fix build
* Tue Jun  9 2009 coolo@novell.com
- continue previous work
* Wed Feb 25 2009 crrodriguez@suse.de
- fix build with GCC44, #ident is a deprecated GCC extension
* Thu Nov  6 2008 ro@suse.de
- fix build failure in obs
* Tue Oct  7 2008 kukuk@suse.de
- Fix possible buffer overflow
* Thu Aug 28 2008 cthiel@suse.de
- fix init scripts
* Wed Dec  5 2007 ro@suse.de
- fix build with gcc-4.3
  (package could possibly be updated anyway)
* Thu Jul 12 2007 rw@suse.de
- Split off development package.
* Thu Mar 29 2007 ro@suse.de
- Add procps,ncurses-devel,bison to buildreq.
* Fri Jun 16 2006 schwab@suse.de
- Set datadir.
- Use RPM_OPT_FLAGS.
* Fri Jun  2 2006 rw@suse.de
- Remove fake dependency on gdbm-devel headers.  (#177730)
* Wed Jan 25 2006 mls@suse.de
- Convert neededforbuild to BuildRequires
* Mon Jan 16 2006 rw@suse.de
- Update to version 2.5.0.  (FATE 153129)
* Thu Oct 20 2005 rw@suse.de
- Fix permission of a demo directory.  (#129486)
* Sat Apr  9 2005 coolo@suse.de
- Fix gcc4 compilation
* Fri Nov 12 2004 ro@suse.de
- Correct permissions handling for pmpost
* Mon Oct 18 2004 nashif@suse.de
- Update to version 2.4.0
* Wed Apr 28 2004 nashif@suse.de
- #39324: fixes for SuSE and 2.6 kernels in general from SGI
* Tue Mar 16 2004 nashif@suse.de
- Update to version 2.3.2
* Wed Nov  5 2003 ro@suse.de
- package according to permissions.secure and add run_permissions
- don't build as root
* Mon Jul 21 2003 nashif@suse.de
- update to version 2.3.1
* Thu Jun 19 2003 nashif@suse.de
- Update to version 2.3.0
- Fixed file list
* Thu Apr 10 2003 ro@suse.de
- fix build with coreutils
  (deprecated calling syntax for head,tail,sort)
* Mon Jan 20 2003 ro@suse.de
- make it compile with latest glibc (pcp-2.2.2-st_mtime.patch)
* Mon Dec  2 2002 ro@suse.de
- include errno.h where needed
- use yacc instead of bison for now (make it compile)
* Fri Aug 16 2002 nashif@suse.de
- Fixed bug #17954: Added PreReq
* Thu Apr 25 2002 coolo@suse.de
- fix build for x86_64 and s390x
* Fri Feb 15 2002 nashif@suse.de
- fix bug #13321: made init script pmie LSB compliant
  - Added header note
  - Status returns correct value
- Fixed pcp init script: status did not work
* Fri Jan 18 2002 nashif@suse.de
- Update to version 2.2.2
* Thu Dec  6 2001 nashif@suse.de
- Removed START_ variable
- Changed escaped { to non escaped to stop awk from complaining
* Mon Jul  9 2001 nashif@suse.de
- Update to version 2.2.1
- Fixed bug # 9068
* Thu Jun  7 2001 nashif@suse.de
- fixed configure.in
* Wed May  9 2001 mfabian@suse.de
- bzip2 sources
* Thu Mar 15 2001 nashif@suse.de
- added -fpic to fix compile error on ia64
* Fri Feb  9 2001 nashif@suse.de
- Update headers
- Modified init scripts
* Sun Dec  3 2000 nashif@suse.de
- Fixed %%post (exit before insserv)
- Added sub-package pcp-mysql
- Added mysql PMDA to monitor mysql sessions
* Thu Nov 30 2000 nashif@suse.de
- Update to 2.2.11
* Wed Nov 29 2000 ro@suse.de
- move rcscript to etc/init.d
* Sun Nov 26 2000 nashif@suse.de
- Use insserv
* Mon Oct 30 2000 nashif@suse.de
- Update to version 2.2.10
* Wed Sep 27 2000 nashif@suse.de
- Update to 2.1.7
* Fri Jul  7 2000 kukuk@suse.de
- Fix for SPARC
* Wed May 24 2000 nashif@suse.de
- Initial Release (2.1.4)
